@@ -1,4 +1,3 @@
-#################################
 #### Base-learner for historic effect of functional covariate
 ### with integral over specific limits, e.g. s<=t
 
@@ -141,7 +140,6 @@ X_histx <- function(mf, vary, args) {
   if(MATRIX){
     # message("use sparse matrix in X_hist")
     diag <- Diagonal
-    cbind <- cBind
     
     ## <enhancement> it would be nicer to construct the matrix directly as sparse matrix 
     
@@ -302,7 +300,7 @@ X_histx <- function(mf, vary, args) {
 #' 
 #' Base-learners that fit historical functional effects that can be used with the 
 #' tensor product, as, e.g., \code{hbistx(...) \%X\% bolsc(...)}, to form interaction 
-#' effects (Ruegamer et al., 2016).  
+#' effects (Ruegamer et al., 2018).  
 #' For expert use only! May show unexpected behavior  
 #' compared to other base-learners for functional data!
 #' 
@@ -353,7 +351,7 @@ X_histx <- function(mf, vary, args) {
 #' \code{bhistx} can only be used if \eqn{Y(t)} and \eqn{x(s)} are observd over
 #' the same domain \eqn{s,t \in [T1, T2]}. 
 #' The base-learner \code{bhistx} can be used to set up complex interaction effects 
-#' like factor-specific historical  effects as discussed in Ruegamer et al. (2016). 
+#' like factor-specific historical  effects as discussed in Ruegamer et al. (2018). 
 #' 
 #' Note that the data has to be supplied as a \code{hmatrix} object for 
 #' model fit and predictions. 
@@ -380,9 +378,9 @@ X_histx <- function(mf, vary, args) {
 #' Marra, G. and Wood, S.N. (2011): Practical variable selection for generalized additive models. 
 #' Computational Statistics & Data Analysis, 55, 2372-2387.
 #' 
-#' Ruegamer D., Brockhaus, S., Gentsch K., Scherer, K., Greven, S. (2016). Detecting synchronisation in 
-#' EEG- and EMG-Signals via boosted functional historical models. 
-#' \url{http://arxiv.org/abs/1609.06070}
+#' Ruegamer D., Brockhaus, S., Gentsch K., Scherer, K., Greven, S. (2018). 
+#' Boosting factor-specific functional historical models for the detection of synchronization in bioelectrical signals. 
+#' Journal of the Royal Statistical Society: Series C (Applied Statistics), 67, 621-642.
 #' 
 #' Scheipl, F., Staicu, A.-M. and Greven, S. (2015): 
 #' Functional Additive Mixed Models, Journal of Computational and Graphical Statistics, 24(2), 477-501.
